# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"/usr/lib/python3.12/site-packages/",
        python_path=r"/usr/bin/python3.12",

        # Package versions
        contourpy_version="1.3.1",
        meson_version="1.6.0",
        mesonpy_version="0.17.1",
        pybind11_version="2.13.6",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"/var/tmp/portage/portage/dev-python/contourpy-1.3.1/work/contourpy-1.3.1-python3_12/lib/contourpy/util",
        source_dir=r"/var/tmp/portage/portage/dev-python/contourpy-1.3.1/work/contourpy-1.3.1/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=plain -Db_ndebug=if-release -Db_vscrt=md -Db_lto=false -Db_pch=false -Dwerror=false -Dprefix=/usr -Dlibdir=lib64 -Dlocalstatedir=/var/lib -Dsysconfdir=/etc -Dwrap_mode=nodownload -Dvsenv=True -Dbuild.pkg_config_path=/var/tmp/portage/portage/dev-python/contourpy-1.3.1/temp/python3.12/pkgconfig:/usr/share/pkgconfig -Dpkg_config_path=/var/tmp/portage/portage/dev-python/contourpy-1.3.1/temp/python3.12/pkgconfig:/usr/share/pkgconfig --native-file=/var/tmp/portage/portage/dev-python/contourpy-1.3.1/temp/meson.aarch64-unknown-linux-gnu.arm64.ini --native-file=/var/tmp/portage/portage/dev-python/contourpy-1.3.1/work/contourpy-1.3.1-python3_12/meson-python-native-file.ini",
        buildtype="plain",
        cpp_std="c++17",
        debug="False",
        optimization="plain",
        vsenv="True",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="gcc",
        compiler_version="14.2.1",
        linker_id="ld.bfd",
        compile_command="aarch64-unknown-linux-gnu-g++",

        # Host machine
        host_cpu="aarch64",
        host_cpu_family="aarch64",
        host_cpu_endian="little",
        host_cpu_system="linux",

        # Build machine, same as host machine if not a cross_build
        build_cpu="aarch64",
        build_cpu_family="aarch64",
        build_cpu_endian="little",
        build_cpu_system="linux",
    )
